summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tabs/tab_strip_model.h
diff options
context:
space:
mode:
authorestade@chromium.org <estade@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-10-02 18:11:09 +0000
committerestade@chromium.org <estade@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-10-02 18:11:09 +0000
commitbfe4c158cd0372fa7a602997f65b42a92645aaf3 (patch)
treedbda26fa776eb9c3b5fcca2e1b1fa956db1985e8 /chrome/browser/tabs/tab_strip_model.h
parent5fa6d7fa100a6836cc7b791a094468f8c384807b (diff)
downloadchromium_src-bfe4c158cd0372fa7a602997f65b42a92645aaf3.zip
chromium_src-bfe4c158cd0372fa7a602997f65b42a92645aaf3.tar.gz
chromium_src-bfe4c158cd0372fa7a602997f65b42a92645aaf3.tar.bz2
Any time we are shutting down a tab, try to use fast shutdown.
BUG=http://crbug.com/5638 TEST=existing tab strip model tests, Fast shutdown ui tests, new tab strip model fast shutdown test Review URL: http://codereview.chromium.org/235050 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@27865 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/tabs/tab_strip_model.h')
-rw-r--r--chrome/browser/tabs/tab_strip_model.h21
1 files changed, 10 insertions, 11 deletions
diff --git a/chrome/browser/tabs/tab_strip_model.h b/chrome/browser/tabs/tab_strip_model.h
index b75a9f86..cbf23a7 100644
--- a/chrome/browser/tabs/tab_strip_model.h
+++ b/chrome/browser/tabs/tab_strip_model.h
@@ -296,9 +296,7 @@ class TabStripModel : public NotificationObserver {
// Returns true if the TabContents was closed immediately, false if it was not
// closed (we may be waiting for a response from an onunload handler, or
// waiting for the user to confirm closure).
- bool CloseTabContentsAt(int index) {
- return InternalCloseTabContentsAt(index, true);
- }
+ bool CloseTabContentsAt(int index);
// Replaces the entire state of a the tab at index by switching in a
// different NavigationController. This is used through the recently
@@ -498,19 +496,20 @@ class TabStripModel : public NotificationObserver {
// something related to their current activity.
bool IsNewTabAtEndOfTabStrip(TabContents* contents) const;
// Closes the TabContents at the specified index. This causes the TabContents
// to be destroyed, but it may not happen immediately (e.g. if it's a
// TabContents). If the page in question has an unload event the TabContents
// will not be destroyed until after the event has completed, which will then
// call back into this method.
//
// The boolean parameter create_historical_tab controls whether to
// record this tab and its history for reopening recently closed
// tabs.
//
- // Returns true if the TabContents was closed immediately, false if we are
+ // Returns true if the TabContents were closed immediately, false if we are
// waiting for the result of an onunload handler.
- bool InternalCloseTabContentsAt(int index, bool create_historical_tab);
+ bool InternalCloseTabs(std::vector<int> indices,
+ bool create_historical_tabs);
void MoveTabContentsAtImpl(int index, int to_position,
bool select_after_move,
@@ -498,19 +496,20 @@ class TabStripModel : public NotificationObserver {
// something related to their current activity.
bool IsNewTabAtEndOfTabStrip(TabContents* contents) const;
- // Closes the TabContents at the specified index. This causes the TabContents
- // to be destroyed, but it may not happen immediately (e.g. if it's a
- // TabContents). If the page in question has an unload event the TabContents
- // will not be destroyed until after the event has completed, which will then
- // call back into this method.
+ // Closes the TabContents at the specified indices. This causes the
+ // TabContents to be destroyed, but it may not happen immediately.
+ // If the page in question has an unload event the
+ // TabContents will not be destroyed until after the event has completed,
+ // which will then call back into this method.
//
// The boolean parameter create_historical_tab controls whether to
@@ -498,19 +496,20 @@ class TabStripModel : public NotificationObserver {
//
// The boolean parameter create_historical_tab controls whether to
- // record this tab and its history for reopening recently closed
+ // record these tabs and their history for reopening recently closed
// tabs.
//